@@ -8,4 +8,4 @@ qc.ry(np.pi*np.random.random(), 0)
 qc.rz(np.pi*np.random.random(), 0)
 
 state = Statevector.from_instruction(qc)
-bloch_disc(state, as_widget=True)
\ No newline at end of file
+bloch_disc(state)
\ No newline at end of file
