@@ -14,4 +14,4 @@ for kk in range(N):
     qc.rz(2*np.pi*np.random.random(), kk)
 
 state = Statevector.from_instruction(qc)
-bloch_multi_disc(state, as_widget=True)
\ No newline at end of file
+bloch_multi_disc(state)
\ No newline at end of file
