@@ -19,5 +19,4 @@ bloch_sphere(points=points,
              vectors=[[0, 0, 1], [1/np.sqrt(2), 1/np.sqrt(2), 0]],
              vectors_color=vectors_color,
              points_alpha=points_alpha,
-             points_color=points_color,
-             as_widget=True)
\ No newline at end of file
+             points_color=points_color)
\ No newline at end of file
