@@ -3,4 +3,4 @@ from kaleidoscope.qiskit.backends import system_error_map
 
 pro = IBMQ.load_account()
 backend = pro.backends.ibmq_vigo
-system_error_map(backend, as_widget=True)
\ No newline at end of file
+system_error_map(backend)
\ No newline at end of file
