@@ -20,6 +20,21 @@ from kaleidoscope.interactive.bloch.utils import bloch_components as bcomp
 
 def bloch_components(self):
     """Returns the Bloch components of the statevector.
+
+    Example:
+
+        .. jupyter-execute::
+
+            from qiskit import QuantumCircuit
+            import kaleidoscope.qiskit
+
+            qc = QuantumCircuit(3)
+            qc.h(range(3))
+            qc.ch(0,1)
+            qc.s(2)
+            qc.cz(2,1)
+
+            qc.statevector().bloch_components()
     """
     return bcomp(self.data)
 
